@@ -226,12 +226,15 @@ extract_content (PopplerDocument *document,
 	GString *string;
 	gint n_pages, i, words;
 	gchar *text, *t;
+	GTimer *timer;
 
 	n_pages = poppler_document_get_n_pages (document);
 	string = g_string_new ("");
 	words = i = 0;
 
-	while (i < n_pages && words < n_words) {
+	timer = g_timer_new ();
+
+	while (i < n_pages && words < n_words && g_timer_elapsed (timer, NULL) < 5) {
 		gint normalized_words;
 
 		page = poppler_document_get_page (document, i);
@@ -240,7 +243,13 @@ extract_content (PopplerDocument *document,
 		rect.x1 = rect.y1 = 0;
 		poppler_page_get_size (page, &rect.x2, &rect.y2);
 
+
+#ifdef HAVE_POPPLER_GLIB_0_14
 		text = poppler_page_get_text (page, POPPLER_SELECTION_WORD, &rect);
+#else
+		text = poppler_page_get_text (page);
+#endif
+
 		t = tracker_text_normalize (text, n_words - words, &normalized_words);
 
 		words += normalized_words;
@@ -251,6 +260,8 @@ extract_content (PopplerDocument *document,
 		g_object_unref (page);
 	}
 
+	g_timer_destroy (timer);
+
 	return g_string_free (string, FALSE);
 }
 
@@ -314,11 +325,20 @@ extract_pdf (const gchar          *uri,
 	document = poppler_document_new_from_file (uri, NULL, &error);
 
 	if (error) {
-		g_warning ("Couldn't create PopplerDocument from uri:'%s', %s",
-		           uri,
-		           error->message ? error->message : "no error given");
-		g_error_free (error);
+		if (error->code == POPPLER_ERROR_ENCRYPTED) {
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "nfo:PaginatedTextDocument");
 
+			tracker_sparql_builder_predicate (metadata, "nfo:isContentEncrypted");
+			tracker_sparql_builder_object_boolean (metadata, TRUE);
+			return;
+		} else {
+			g_warning ("Couldn't create PopplerDocument from uri:'%s', %s",
+			           uri,
+			           error->message ? error->message : "no error given");
+		}
+
+		g_error_free (error);
 		return;
 	}
 
